# Authors and contributors

- Moul, Maël Azimi <ma.azimi@moul.re>
- Matograine <tom.ngr@zaclys.net>
- Tortue <ucoin@tednet.fr>
- cebash, Sébastien DA ROCHA <sebastien@da-rocha.net>
- atrax, <duniter@karam.email>
- cgeek, Cédric Moreau <cem.moreau@gmail.com>
- jytou, Jean-Yves Toumit <jytoumit@gmail.com>
- Bernard <bernard@dugas-family.org>
- ManUtopiK, Emmanuel Salomon <emmanuel.salomon@gmail.com>
- mmuman, François Revol
- MrNem, Pi Nguyen <nguyenpi@hotmail.com>
- vtexier, Vincent Texier <vit@free.fr>
- vincentux, <vincentux@vincentux.fr>
